==> etchibbs-spiral-1.0.0.tar.gz: etchibbs-spiral/config_ok.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: config_ok.php,v 1.13.2.1 2004/01/23 08:27:33 lseeker Exp $
 */

require 'lib/admin.inc'; // 관리자 환경설정
include 'lib/message.inc'; // 메시지 function

if(!$admin['login']) {
    // 관리자 쿠키가 없을 경우
    die('ERROR: 관리자 쿠키를 찾을 수 없습니다.');
}

/* 비밀번호 확인, 비번이 비어있다면 현재 비번으로 그냥 처리 */
if (strcmp($_POST['admin_pass'], '')) {
    mt_srand(microtime() * 1e6);
    $salt = chr(mt_rand(0x21, 0x7E)) . chr(mt_rand(0x21, 0x7E));
    $admin_pass = addslashes(crypt($_POST['admin_pass'], $salt));
    /* 비번 변경시 쿠키를 다시 구워줌 */
    setcookie('hboard_admin_login', $admin_pass); // 관리자 쿠키 넣어주기
} else {
    $admin_pass = addslashes($admin_data['passwd']);
}

$_POST['article_per_page'] = (int) $_POST['article_per_page'];
$_POST['fileup_max']       = (int) $_POST['fileup_max'];
$_POST['width_max']        = (int) $_POST['width_max'];

if (!get_magic_quotes_gpc()) {
    $_POST['title_text'] = addslashes($_POST['title_text']);
    $_POST['board_skin'] = addslashes($_POST['board_skin']);
    $_POST['use_html']   = addslashes($_POST['use_html']);
    $_POST['include_up'] = addslashes($_POST['include_up']);
    $_POST['include_bt'] = addslashes($_POST['include_bt']);
    $_POST['bgimage']    = addslashes($_POST['bgimage']);
    $_POST['titlebar']   = addslashes($_POST['titlebar']);
    $_POST['autolink']   = addslashes($_POST['autolink']);
    $_POST['backdrum']   = addslashes($_POST['backdrum']);
}

/* FIXME LANG??? ARTICLE_MAX는 현재 미지원 기능. */
DB::query("UPDATE hboard_db_admin SET
        passwd='{$admin_pass}',
        title_text='{$_POST['title_text']}',
        app='{$_POST['article_per_page']}',
        skin='{$_POST['board_skin']}',
        fileup_max='{$_POST['fileup_max']}',
        html_tag='{$_POST['use_html']}',
        include_top='{$_POST['include_up']}',
        include_bottom='{$_POST['include_bt']}',
        bgimage='{$_POST['bgimage']}',
        width_max='{$_POST['width_max']}',
        titlebar='{$_POST['titlebar']}',
        autolink='{$_POST['autolink']}',
        backdrum='{$_POST['backdrum']}'",
        $dbconn) or die("설정을 저장하지 못했습니다! DB를 확인해 주세요.");

DB::close($dbconn);

// 처리 끝;
header('Content-Type: text/html; charset=UTF-8');
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
 <title>Query Completed</title>
</head>

<body>
 <script type="text/javascript">
<!--
window.opener.location.href = '<?php echo htmlspecialchars(get_magic_quotes_gpc() ? stripslashes($_POST['from']) : $_POST['from'], ENT_QUOTES); ?>';
window.close();
//-->
 </script>
</body>
</html>

==> etchibbs-spiral-1.1.1.tar.gz: etchibbs-spiral/config_ok.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: config_ok.php,v 1.15 2004/01/24 06:01:11 lseeker Exp $
 */

require 'lib/admin.inc'; // 관리자 환경설정
include 'lib/message.inc'; // 메시지 function

if(!$admin['login']) {
    // 관리자 쿠키가 없을 경우
    die('ERROR: 관리자 쿠키를 찾을 수 없습니다.');
}

/* 비밀번호 확인, 비번이 비어있다면 현재 비번으로 그냥 처리 */
if (strcmp($_POST['admin_pass'], '')) {
    mt_srand(microtime() * 1e6);
    $salt = chr(mt_rand(0x21, 0x7E)) . chr(mt_rand(0x21, 0x7E));
    $admin_pass = addslashes(crypt($_POST['admin_pass'], $salt));
    /* 비번 변경시 쿠키를 다시 구워줌 */
    setcookie('hboard_admin_login', $admin_pass); // 관리자 쿠키 넣어주기
} else {
    $admin_pass = addslashes($admin_data['passwd']);
}

$_POST['article_per_page'] = (int) $_POST['article_per_page'];
$_POST['fileup_max']       = (int) $_POST['fileup_max'];
$_POST['width_max']        = (int) $_POST['width_max'];

if (!get_magic_quotes_gpc()) {
    $_POST['title_text'] = addslashes($_POST['title_text']);
    $_POST['board_skin'] = addslashes($_POST['board_skin']);
    $_POST['use_html']   = addslashes($_POST['use_html']);
    $_POST['include_up'] = addslashes($_POST['include_up']);
    $_POST['include_bt'] = addslashes($_POST['include_bt']);
    $_POST['bgimage']    = addslashes($_POST['bgimage']);
    $_POST['titlebar']   = addslashes($_POST['titlebar']);
    $_POST['autolink']   = addslashes($_POST['autolink']);
    $_POST['backdrum']   = addslashes($_POST['backdrum']);
}

/* FIXME LANG??? ARTICLE_MAX는 현재 미지원 기능. */
DB::query("UPDATE hboard_db_admin SET
        passwd='{$admin_pass}',
        title_text='{$_POST['title_text']}',
        app='{$_POST['article_per_page']}',
        skin='{$_POST['board_skin']}',
        fileup_max='{$_POST['fileup_max']}',
        html_tag='{$_POST['use_html']}',
        include_top='{$_POST['include_up']}',
        include_bottom='{$_POST['include_bt']}',
        bgimage='{$_POST['bgimage']}',
        width_max='{$_POST['width_max']}',
        titlebar='{$_POST['titlebar']}',
        autolink='{$_POST['autolink']}',
        backdrum='{$_POST['backdrum']}'",
        $dbconn) or die("설정을 저장하지 못했습니다! DB를 확인해 주세요.");

DB::close($dbconn);

// 처리 끝;
header('Content-Type: text/html; charset=UTF-8');
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
 <title>Query Completed</title>
</head>

<body>
 <script type="text/javascript">
<!--
window.opener.location.href = '<?php echo str_replace('\'', '\\\'', get_magic_quotes_gpc() ? stripslashes($_POST['from']) : $_POST['from']); ?>';
window.close();
//-->
 </script>
</body>
</html>
